"""
pathing.py

Fancy path-related functions, classes, etc.

:author:        Stephen Stauts
:created:       07/03/2020   (DD/MM/YYYY)
:copyright:     © 2020 Stephen Stauts. All Rights Reserved.
"""

# Standard Packages
import os
from pathlib import Path

# Dependency Packages
try:
    import git       # Not a hard requirement; functions disabled otherwise
except ImportError:
    GITPYTHON_EXISTS = False
else:
    GITPYTHON_EXISTS = True

# Local Packages and Modules


def get_repo_root_path(**kwargs):
    """
    Return the path to the directory of the current repository root.

    If this is called from within a submodule, its name can be passed in to avoid seeing
    root as a submodule repository.

    :kwarg str submodule:   Name of the current submodule

    :return Path:           The path of the root directory
    """
    if not GITPYTHON_EXISTS:
        raise ImportError('The gitpython package is not installed.')

    submodule = kwargs.get('submodule', '')

    current_repo = git.Repo(os.getcwd(), search_parent_directories=True)
    repo_path = Path(current_repo.git.rev_parse('--show-toplevel'))

    if submodule and (submodule in repo_path):
        # THIS NEEDS TO BE FIXED
        # Create a separate function that returns the path up to a parent folder's name, then use that here
        master_repo_path = repo_path.split(submodule)[0]
        repo_path = Path(split_path)

    return repo_path.absolute()
