"""
testing.py

Fancy test utilities.

:author:        Stephen Stauts
:created:       22/03/2020   (DD/MM/YYYY)
:copyright:     © 2020 Stephen Stauts. All Rights Reserved.
"""

# Standard Packages
from contextlib import contextmanager

# Dependency Packages
try:
    import pytest       # Not a hard requirement; functions disabled otherwise
except ImportError:
    PYTEST_EXISTS = False
else:
    PYTEST_EXISTS = True

# Local Packages and Modules


@contextmanager
def does_not_raise(exception : Exception):
    """
    Opposite of built-in raises context manager, evaluating that an exception
    did not occur.

    :reference: https://stackoverflow.com/a/42327075
    """
    if not PYTEST_EXISTS:
        raise ImportError('The pytest package is not installed.')

    try:
        yield
    except exception:
        raise pytest.fail('Test raised exception: {}'.format(exception))
